3.1
===

* Add excuse.

3.0
===

* Drop support for Python 3.4 and earlier, including Python 2.
* Use literal TM character in excuses.

2.6
===

* Add excuse.

2.5
===

* Add excuse.

2.4
===

* Refresh project skeleton.
* Add excuse.

2.3
===

* Refresh project skeleton.
* Add excuse.

2.0
===

* Moved hosting to Github.
* Dropped support for Python 2.6.
